 #if !defined(MQC_INCLUDED)            /* File not yet included?      */
   #define MQC_INCLUDED                /* Show file now included      */
 /*********************************************************************/
 /*                                                                   */
 /*  Program name:  CMQC                                              */
 /*                                                                   */
 /*  Description:   This file declares functions, structures, and     */
 /*                 constants for the IBM Message Queue Interface     */
 /*                 (MQI) in the PC-DOS environment.                  */
 /*                                                                   */
 /*                                                                   */
 /*                                                                   */
 /*  Statement:     Licensed Materials - Property of IBM              */
 /*                                                                   */
 /*                 33H2205, 5622-908                                 */ 
 /*                 (C) Copyright IBM Corp. 1995                      */ 
 /*                                                                   */
 /*                                                                   */
 /*  Status:        Version 2 Release 0.1                             */
 /*                                                                   */
 /*********************************************************************/

 #if defined(__cplusplus)
   extern "C" {
 #endif

 /*********************************************************************/
 /*  Values Related to MQDLH Structure                                */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQDLH_STRUC_ID "DLH "

 /* Structure Identifier (array form) */
 #define MQDLH_STRUC_ID_ARRAY 'D','L','H',' '

 /* Structure Version Number */
 #define MQDLH_VERSION_1 1L


 /*********************************************************************/
 /*  Values Related to MQGMO Structure                                */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQGMO_STRUC_ID "GMO "

 /* Structure Identifier (array form) */
 #define MQGMO_STRUC_ID_ARRAY 'G','M','O',' '

 /* Structure Version Number */
 #define MQGMO_VERSION_1 1L

 /* Get-Message Options */
 #define MQGMO_WAIT                    1L
 #define MQGMO_NO_WAIT                 0L
 #define MQGMO_SYNCPOINT               2L
 #define MQGMO_NO_SYNCPOINT            4L
 #define MQGMO_SYNCPOINT_IF_PERSISTENT 4096L
 #define MQGMO_BROWSE_FIRST            16L
 #define MQGMO_BROWSE_NEXT             32L
 #define MQGMO_BROWSE_MSG_UNDER_CURSOR 2048L
 #define MQGMO_MSG_UNDER_CURSOR        256L
 #define MQGMO_LOCK                    512L
 #define MQGMO_UNLOCK                  1024L
 #define MQGMO_ACCEPT_TRUNCATED_MSG    64L
 #define MQGMO_FAIL_IF_QUIESCING       8192L
 #define MQGMO_CONVERT                 16384L
 #define MQGMO_NONE                    0L

 /* Wait Interval */
 #define MQWI_UNLIMITED (-1L)


 /*********************************************************************/
 /*  Values Related to MQMD Structure                                 */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQMD_STRUC_ID "MD  "

 /* Structure Identifier (array form) */
 #define MQMD_STRUC_ID_ARRAY 'M','D',' ',' '

 /* Structure Version Number */
 #define MQMD_VERSION_1 1L

 /* Report Options */
 #define MQRO_EXCEPTION                 0x01000000L
 #define MQRO_EXCEPTION_WITH_DATA       0x03000000L
 #define MQRO_EXCEPTION_WITH_FULL_DATA  0x07000000L
 #define MQRO_EXPIRATION                0x00200000L
 #define MQRO_EXPIRATION_WITH_DATA      0x00600000L
 #define MQRO_EXPIRATION_WITH_FULL_DATA 0x00e00000L
 #define MQRO_COA                       0x00000100L
 #define MQRO_COA_WITH_DATA             0x00000300L
 #define MQRO_COA_WITH_FULL_DATA        0x00000700L
 #define MQRO_COD                       0x00000800L
 #define MQRO_COD_WITH_DATA             0x00001800L
 #define MQRO_COD_WITH_FULL_DATA        0x00003800L
 #define MQRO_COPY_MSG_ID_TO_CORREL_ID  0x00000000L
 #define MQRO_PASS_CORREL_ID            0x00000040L
 #define MQRO_NEW_MSG_ID                0x00000000L
 #define MQRO_PASS_MSG_ID               0x00000080L
 #define MQRO_DEAD_LETTER_Q             0x00000000L
 #define MQRO_DISCARD_MSG               0x08000000L
 #define MQRO_NONE                      0x00000000L

 /* Report Options Masks */
 #define MQRO_REJECT_UNSUP_MASK         0x101c0000L
 #define MQRO_ACCEPT_UNSUP_MASK         0xefe000ffL
 #define MQRO_ACCEPT_UNSUP_IF_XMIT_MASK 0x0003ff00L

 /* Message Types */
 #define MQMT_SYSTEM_FIRST 1L
 #define MQMT_REQUEST      1L
 #define MQMT_REPLY        2L
 #define MQMT_DATAGRAM     8L
 #define MQMT_REPORT       4L
 #define MQMT_SYSTEM_LAST  65535L
 #define MQMT_APPL_FIRST   65536L
 #define MQMT_APPL_LAST    999999999L

 /* Expiry */
 #define MQEI_UNLIMITED (-1L)

 /* Feedback Values */
 #define MQFB_NONE                   0L
 #define MQFB_SYSTEM_FIRST           1L
 #define MQFB_EXPIRATION             258L
 #define MQFB_COA                    259L
 #define MQFB_COD                    260L
 #define MQFB_QUIT                   256L
 #define MQFB_CHANNEL_COMPLETED      262L
 #define MQFB_CHANNEL_FAIL_RETRY     263L
 #define MQFB_CHANNEL_FAIL           264L
 #define MQFB_APPL_CANNOT_BE_STARTED 265L
 #define MQFB_TM_ERROR               266L
 #define MQFB_APPL_TYPE_ERROR        267L
 #define MQFB_STOPPED_BY_MSG_EXIT    268L
 #define MQFB_XMIT_Q_MSG_ERROR       271L
 #define MQFB_SYSTEM_LAST            65535L
 #define MQFB_APPL_FIRST             65536L
 #define MQFB_APPL_LAST              999999999L

 /* Encoding */
 #define MQENC_NATIVE 0x00000222L

 /* Encoding Masks */
 #define MQENC_INTEGER_MASK  0x0000000fL
 #define MQENC_DECIMAL_MASK  0x000000f0L
 #define MQENC_FLOAT_MASK    0x00000f00L
 #define MQENC_RESERVED_MASK 0xfffff000L

 /* Encodings for Binary Integers */
 #define MQENC_INTEGER_UNDEFINED 0x00000000L
 #define MQENC_INTEGER_NORMAL    0x00000001L
 #define MQENC_INTEGER_REVERSED  0x00000002L

 /* Encodings for Packed-Decimal Integers */
 #define MQENC_DECIMAL_UNDEFINED 0x00000000L
 #define MQENC_DECIMAL_NORMAL    0x00000010L
 #define MQENC_DECIMAL_REVERSED  0x00000020L

 /* Encodings for Floating-Point Numbers */
 #define MQENC_FLOAT_UNDEFINED     0x00000000L
 #define MQENC_FLOAT_IEEE_NORMAL   0x00000100L
 #define MQENC_FLOAT_IEEE_REVERSED 0x00000200L
 #define MQENC_FLOAT_S390          0x00000300L

 /* Coded Character-Set Identifiers */
 #define MQCCSI_DEFAULT  0L
 #define MQCCSI_Q_MGR    0L
 #define MQCCSI_EMBEDDED (-1L)

 /* Formats */
 #define MQFMT_NONE               "        "
 #define MQFMT_ADMIN              "MQADMIN "
 #define MQFMT_CHANNEL_COMPLETED  "MQCHCOM "
 #define MQFMT_COMMAND_1          "MQCMD1  "
 #define MQFMT_COMMAND_2          "MQCMD2  "
 #define MQFMT_DEAD_LETTER_HEADER "MQDEAD  "
 #define MQFMT_EVENT              "MQEVENT "
 #define MQFMT_PCF                "MQPCF   "
 #define MQFMT_STRING             "MQSTR   "
 #define MQFMT_TRIGGER            "MQTRIG  "
 #define MQFMT_XMIT_Q_HEADER      "MQXMIT  "

 /* Formats (array form) */
 #define MQFMT_NONE_ARRAY               ' ',' ',' ',' ',' ',' ',' ',' '
 #define MQFMT_ADMIN_ARRAY              'M','Q','A','D','M','I','N',' '
 #define MQFMT_CHANNEL_COMPLETED_ARRAY  'M','Q','C','H','C','O','M',' '
 #define MQFMT_COMMAND_1_ARRAY          'M','Q','C','M','D','1',' ',' '
 #define MQFMT_COMMAND_2_ARRAY          'M','Q','C','M','D','2',' ',' '
 #define MQFMT_DEAD_LETTER_HEADER_ARRAY 'M','Q','D','E','A','D',' ',' '
 #define MQFMT_EVENT_ARRAY              'M','Q','E','V','E','N','T',' '
 #define MQFMT_PCF_ARRAY                'M','Q','P','C','F',' ',' ',' '
 #define MQFMT_STRING_ARRAY             'M','Q','S','T','R',' ',' ',' '
 #define MQFMT_TRIGGER_ARRAY            'M','Q','T','R','I','G',' ',' '
 #define MQFMT_XMIT_Q_HEADER_ARRAY      'M','Q','X','M','I','T',' ',' '

 /* Priority */
 #define MQPRI_PRIORITY_AS_Q_DEF (-1L)

 /* Persistence Values */
 #define MQPER_PERSISTENT           1L
 #define MQPER_NOT_PERSISTENT       0L
 #define MQPER_PERSISTENCE_AS_Q_DEF 2L

 /* Message Id */
 #define MQMI_NONE "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"

 /* Message Id (array form) */
 #define MQMI_NONE_ARRAY \
     '\0','\0','\0','\0','\0','\0','\0','\0',\
     '\0','\0','\0','\0','\0','\0','\0','\0',\
     '\0','\0','\0','\0','\0','\0','\0','\0'

 /* Correlation Id */
 #define MQCI_NONE "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"

 /* Correlation Id (array form) */
 #define MQCI_NONE_ARRAY \
     '\0','\0','\0','\0','\0','\0','\0','\0',\
     '\0','\0','\0','\0','\0','\0','\0','\0',\
     '\0','\0','\0','\0','\0','\0','\0','\0'

 /* Accounting Token */
 #define MQACT_NONE "\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0"\
                    "\0\0\0\0\0\0\0\0\0"

 /* Accounting Token (array form) */
 #define MQACT_NONE_ARRAY \
     '\0','\0','\0','\0','\0','\0','\0','\0',\
     '\0','\0','\0','\0','\0','\0','\0','\0',\
     '\0','\0','\0','\0','\0','\0','\0','\0',\
     '\0','\0','\0','\0','\0','\0','\0','\0'

 /* Put Application Types */
 #define MQAT_UNKNOWN    (-1L)
 #define MQAT_NO_CONTEXT 0L
 #define MQAT_CICS       1L
 #define MQAT_MVS        2L
 #define MQAT_IMS        3L
 #define MQAT_OS2        4L
 #define MQAT_DOS        5L
 #define MQAT_AIX        6L
 #define MQAT_UNIX       6L
 #define MQAT_QMGR       7L
 #define MQAT_OS400      8L
 #define MQAT_WINDOWS    9L
 #define MQAT_CICS_VSE   10L
 #define MQAT_WINDOWS_NT 11L
 #define MQAT_VMS        12L
 #define MQAT_GUARDIAN   13L
 #define MQAT_VOS        14L
 #define MQAT_DEFAULT    5L
 #define MQAT_USER_FIRST 65536L
 #define MQAT_USER_LAST  999999999L


 /*********************************************************************/
 /*  Values Related to MQOD Structure                                 */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQOD_STRUC_ID "OD  "

 /* Structure Identifier (array form) */
 #define MQOD_STRUC_ID_ARRAY 'O','D',' ',' '

 /* Structure Version Number */
 #define MQOD_VERSION_1 1L

 /* Object Types */
 #define MQOT_Q       1L
 #define MQOT_PROCESS 3L
 #define MQOT_Q_MGR   5L
 #define MQOT_CHANNEL 6L

 /* Extended Object Types */
 #define MQOT_ALL               1001L
 #define MQOT_ALIAS_Q           1002L
 #define MQOT_MODEL_Q           1003L
 #define MQOT_LOCAL_Q           1004L
 #define MQOT_REMOTE_Q          1005L
 #define MQOT_SENDER_CHANNEL    1007L
 #define MQOT_SERVER_CHANNEL    1008L
 #define MQOT_REQUESTER_CHANNEL 1009L
 #define MQOT_RECEIVER_CHANNEL  1010L
 #define MQOT_CURRENT_CHANNEL   1011L
 #define MQOT_SAVED_CHANNEL     1012L


 /*********************************************************************/
 /*  Values Related to MQPMO Structure                                */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQPMO_STRUC_ID "PMO "

 /* Structure Identifier (array form) */
 #define MQPMO_STRUC_ID_ARRAY 'P','M','O',' '

 /* Structure Version Number */
 #define MQPMO_VERSION_1 1L

 /* Put-Message Options */
 #define MQPMO_SYNCPOINT                2L
 #define MQPMO_NO_SYNCPOINT             4L
 #define MQPMO_NO_CONTEXT               16384L
 #define MQPMO_DEFAULT_CONTEXT          32L
 #define MQPMO_PASS_IDENTITY_CONTEXT    256L
 #define MQPMO_PASS_ALL_CONTEXT         512L
 #define MQPMO_SET_IDENTITY_CONTEXT     1024L
 #define MQPMO_SET_ALL_CONTEXT          2048L
 #define MQPMO_ALTERNATE_USER_AUTHORITY 4096L
 #define MQPMO_FAIL_IF_QUIESCING        8192L
 #define MQPMO_NONE                     0L


 /*********************************************************************/
 /*  Values Related to MQTM Structure                                 */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQTM_STRUC_ID "TM  "

 /* Structure Identifier (array form) */
 #define MQTM_STRUC_ID_ARRAY 'T','M',' ',' '

 /* Structure Version Number */
 #define MQTM_VERSION_1 1L


 /*********************************************************************/
 /*  Values Related to MQTMC2 Structure                               */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQTMC_STRUC_ID "TMC "

 /* Structure Identifier (array form) */
 #define MQTMC_STRUC_ID_ARRAY 'T','M','C',' '

 /* Structure Version Number */
 #define MQTMC_VERSION_1 "   1"
 #define MQTMC_VERSION_2 "   2"

 /* Structure Version Number (array form) */
 #define MQTMC_VERSION_1_ARRAY ' ',' ',' ','1'
 #define MQTMC_VERSION_2_ARRAY ' ',' ',' ','2'


 /*********************************************************************/
 /*  Values Related to MQXQH Structure                                */
 /*********************************************************************/

 /* Structure Identifier */
 #define MQXQH_STRUC_ID "XQH "

 /* Structure Identifier (array form) */
 #define MQXQH_STRUC_ID_ARRAY 'X','Q','H',' '

 /* Structure Version Number */
 #define MQXQH_VERSION_1 1L


 /*********************************************************************/
 /*  Values Related to MQCLOSE Function                               */
 /*********************************************************************/

 /* Object Handle */
 #define MQHO_UNUSABLE_HOBJ (-1L)

 /* Close Options */
 #define MQCO_NONE         0L
 #define MQCO_DELETE       1L
 #define MQCO_DELETE_PURGE 2L


 /*********************************************************************/
 /*  Values Related to MQINQ Function                                 */
 /*********************************************************************/

 /* Character-Attribute Selectors */
 #define MQCA_APPL_ID              2001L
 #define MQCA_BACKOUT_REQ_Q_NAME   2019L
 #define MQCA_BASE_Q_NAME          2002L
 #define MQCA_COMMAND_INPUT_Q_NAME 2003L
 #define MQCA_CREATION_DATE        2004L
 #define MQCA_CREATION_TIME        2005L
 #define MQCA_DEAD_LETTER_Q_NAME   2006L
 #define MQCA_DEF_XMIT_Q_NAME      2025L
 #define MQCA_ENV_DATA             2007L
 #define MQCA_FIRST                2001L
 #define MQCA_INITIATION_Q_NAME    2008L
 #define MQCA_LAST                 4000L
 #define MQCA_LAST_USED            2025L
 #define MQCA_NAMES                2020L
 #define MQCA_PROCESS_DESC         2011L
 #define MQCA_PROCESS_NAME         2012L
 #define MQCA_Q_DESC               2013L
 #define MQCA_Q_MGR_DESC           2014L
 #define MQCA_Q_MGR_NAME           2015L
 #define MQCA_Q_NAME               2016L
 #define MQCA_REMOTE_Q_MGR_NAME    2017L
 #define MQCA_REMOTE_Q_NAME        2018L
 #define MQCA_STORAGE_CLASS        2022L
 #define MQCA_TRIGGER_DATA         2023L
 #define MQCA_USER_DATA            2021L
 #define MQCA_XMIT_Q_NAME          2024L

 /* Integer-Attribute Selectors */
 #define MQIA_APPL_TYPE                1L
 #define MQIA_AUTHORITY_EVENT          47L
 #define MQIA_BACKOUT_THRESHOLD        22L
 #define MQIA_CODED_CHAR_SET_ID        2L
 #define MQIA_COMMAND_LEVEL            31L
 #define MQIA_CURRENT_Q_DEPTH          3L
 #define MQIA_DEF_INPUT_OPEN_OPTION    4L
 #define MQIA_DEF_PERSISTENCE          5L
 #define MQIA_DEF_PRIORITY             6L
 #define MQIA_DEFINITION_TYPE          7L
 #define MQIA_FIRST                    1L
 #define MQIA_HARDEN_GET_BACKOUT       8L
 #define MQIA_HIGH_Q_DEPTH             36L
 #define MQIA_INHIBIT_EVENT            48L
 #define MQIA_INHIBIT_GET              9L
 #define MQIA_INHIBIT_PUT              10L
 #define MQIA_LAST                     2000L
 #define MQIA_LAST_USED                54L
 #define MQIA_LOCAL_EVENT              49L
 #define MQIA_MAX_HANDLES              11L
 #define MQIA_MAX_MSG_LENGTH           13L
 #define MQIA_MAX_PRIORITY             14L
 #define MQIA_MAX_Q_DEPTH              15L
 #define MQIA_MAX_UNCOMMITTED_MSGS     33L
 #define MQIA_MSG_DELIVERY_SEQUENCE    16L
 #define MQIA_MSG_DEQ_COUNT            38L
 #define MQIA_MSG_ENQ_COUNT            37L
 #define MQIA_NAME_COUNT               19L
 #define MQIA_OPEN_INPUT_COUNT         17L
 #define MQIA_OPEN_OUTPUT_COUNT        18L
 #define MQIA_PERFORMANCE_EVENT        53L
 #define MQIA_PLATFORM                 32L
 #define MQIA_Q_DEPTH_HIGH_EVENT       43L
 #define MQIA_Q_DEPTH_HIGH_LIMIT       40L
 #define MQIA_Q_DEPTH_LOW_EVENT        44L
 #define MQIA_Q_DEPTH_LOW_LIMIT        41L
 #define MQIA_Q_DEPTH_MAX_EVENT        42L
 #define MQIA_Q_SERVICE_INTERVAL       54L
 #define MQIA_Q_SERVICE_INTERVAL_EVENT 46L
 #define MQIA_Q_TYPE                   20L
 #define MQIA_REMOTE_EVENT             50L
 #define MQIA_RETENTION_INTERVAL       21L
 #define MQIA_SCOPE                    45L
 #define MQIA_SHAREABILITY             23L
 #define MQIA_START_STOP_EVENT         52L
 #define MQIA_SYNCPOINT                30L
 #define MQIA_TIME_SINCE_RESET         35L
 #define MQIA_TRIGGER_CONTROL          24L
 #define MQIA_TRIGGER_DEPTH            29L
 #define MQIA_TRIGGER_INTERVAL         25L
 #define MQIA_TRIGGER_MSG_PRIORITY     26L
 #define MQIA_TRIGGER_TYPE             28L
 #define MQIA_USAGE                    12L

 /* Integer Attribute Value Denoting "Not Applicable" */
 #define MQIAV_NOT_APPLICABLE (-1L)


 /*********************************************************************/
 /*  Values Related to MQOPEN Function                                */
 /*********************************************************************/

 /* Open Options */
 #define MQOO_INPUT_AS_Q_DEF           1L
 #define MQOO_INPUT_SHARED             2L
 #define MQOO_INPUT_EXCLUSIVE          4L
 #define MQOO_BROWSE                   8L
 #define MQOO_OUTPUT                   16L
 #define MQOO_INQUIRE                  32L
 #define MQOO_SET                      64L
 #define MQOO_SAVE_ALL_CONTEXT         128L
 #define MQOO_PASS_IDENTITY_CONTEXT    256L
 #define MQOO_PASS_ALL_CONTEXT         512L
 #define MQOO_SET_IDENTITY_CONTEXT     1024L
 #define MQOO_SET_ALL_CONTEXT          2048L
 #define MQOO_ALTERNATE_USER_AUTHORITY 4096L
 #define MQOO_FAIL_IF_QUIESCING        8192L


 /*********************************************************************/
 /*  Values Related to All Functions                                  */
 /*********************************************************************/

 /* Function Entry-Point and Pointer Attributes */
 #if defined(__BORLANDC__)
   #define MQENTRY   __syscall
   #define MQPOINTER *
 #elif defined(__32BIT__)
   #define MQENTRY   _System
   #define MQPOINTER *
 #else
   #define MQENTRY   _far _pascal _loadds
   #define MQPOINTER _far*
 #endif

 /* Connection Handle */
 #define MQHC_UNUSABLE_HCONN (-1L)

 /* String Lengths */
 #define MQ_ACCOUNTING_TOKEN_LENGTH   32L
 #define MQ_APPL_IDENTITY_DATA_LENGTH 32L
 #define MQ_APPL_NAME_LENGTH          28L
 #define MQ_APPL_ORIGIN_DATA_LENGTH   4L
 #define MQ_CHANNEL_DATE_LENGTH       12L
 #define MQ_CHANNEL_DESC_LENGTH       64L
 #define MQ_CHANNEL_NAME_LENGTH       20L
 #define MQ_CHANNEL_TIME_LENGTH       8L
 #define MQ_CONN_NAME_LENGTH          264L
 #define MQ_CORREL_ID_LENGTH          24L
 #define MQ_CREATION_DATE_LENGTH      12L
 #define MQ_CREATION_TIME_LENGTH      8L
 #define MQ_EXIT_DATA_LENGTH          32L
 #define MQ_EXIT_NAME_LENGTH          128L
 #define MQ_EXIT_USER_AREA_LENGTH     16L
 #define MQ_FORMAT_LENGTH             8L
 #define MQ_LUWID_LENGTH              16L
 #define MQ_MCA_JOB_NAME_LENGTH       28L
 #define MQ_MCA_NAME_LENGTH           20L
 #define MQ_MODE_NAME_LENGTH          8L
 #define MQ_MSG_HEADER_LENGTH         4000L
 #define MQ_MSG_ID_LENGTH             24L
 #define MQ_PASSWORD_LENGTH           12L
 #define MQ_PROCESS_APPL_ID_LENGTH    256L
 #define MQ_PROCESS_DESC_LENGTH       64L
 #define MQ_PROCESS_ENV_DATA_LENGTH   128L
 #define MQ_PROCESS_NAME_LENGTH       48L
 #define MQ_PROCESS_USER_DATA_LENGTH  128L
 #define MQ_PUT_APPL_NAME_LENGTH      28L
 #define MQ_PUT_DATE_LENGTH           8L
 #define MQ_PUT_TIME_LENGTH           8L
 #define MQ_Q_DESC_LENGTH             64L
 #define MQ_Q_NAME_LENGTH             48L
 #define MQ_Q_MGR_DESC_LENGTH         64L
 #define MQ_Q_MGR_NAME_LENGTH         48L
 #define MQ_SHORT_CONN_NAME_LENGTH    20L
 #define MQ_STORAGE_CLASS_LENGTH      8L
 #define MQ_TP_NAME_LENGTH            64L
 #define MQ_TRIGGER_DATA_LENGTH       64L
 #define MQ_USER_ID_LENGTH            12L

 /* Completion Codes */
 #define MQCC_OK      0L
 #define MQCC_WARNING 1L
 #define MQCC_FAILED  2L
 #define MQCC_UNKNOWN (-1L)

 /* Reason Codes */
 #define MQRC_NONE                      0L
 #define MQRC_ALIAS_BASE_Q_TYPE_ERROR   2001L
 #define MQRC_ALREADY_CONNECTED         2002L
 #define MQRC_BACKED_OUT                2003L
 #define MQRC_BUFFER_ERROR              2004L
 #define MQRC_BUFFER_LENGTH_ERROR       2005L
 #define MQRC_CHAR_ATTR_LENGTH_ERROR    2006L
 #define MQRC_CHAR_ATTRS_ERROR          2007L
 #define MQRC_CHAR_ATTRS_TOO_SHORT      2008L
 #define MQRC_CONNECTION_BROKEN         2009L
 #define MQRC_DATA_LENGTH_ERROR         2010L
 #define MQRC_DYNAMIC_Q_NAME_ERROR      2011L
 #define MQRC_ENVIRONMENT_ERROR         2012L
 #define MQRC_EXPIRY_ERROR              2013L
 #define MQRC_FEEDBACK_ERROR            2014L
 #define MQRC_GET_INHIBITED             2016L
 #define MQRC_HANDLE_NOT_AVAILABLE      2017L
 #define MQRC_HCONN_ERROR               2018L
 #define MQRC_HOBJ_ERROR                2019L
 #define MQRC_INHIBIT_VALUE_ERROR       2020L
 #define MQRC_INT_ATTR_COUNT_ERROR      2021L
 #define MQRC_INT_ATTR_COUNT_TOO_SMALL  2022L
 #define MQRC_INT_ATTRS_ARRAY_ERROR     2023L
 #define MQRC_SYNCPOINT_LIMIT_REACHED   2024L
 #define MQRC_MAX_CONNS_LIMIT_REACHED   2025L
 #define MQRC_MD_ERROR                  2026L
 #define MQRC_MISSING_REPLY_TO_Q        2027L
 #define MQRC_MSG_TYPE_ERROR            2029L
 #define MQRC_MSG_TOO_BIG_FOR_Q         2030L
 #define MQRC_MSG_TOO_BIG_FOR_Q_MGR     2031L
 #define MQRC_NO_MSG_AVAILABLE          2033L
 #define MQRC_NO_MSG_UNDER_CURSOR       2034L
 #define MQRC_NOT_AUTHORIZED            2035L
 #define MQRC_NOT_OPEN_FOR_BROWSE       2036L
 #define MQRC_NOT_OPEN_FOR_INPUT        2037L
 #define MQRC_NOT_OPEN_FOR_INQUIRE      2038L
 #define MQRC_NOT_OPEN_FOR_OUTPUT       2039L
 #define MQRC_NOT_OPEN_FOR_SET          2040L
 #define MQRC_OBJECT_CHANGED            2041L
 #define MQRC_OBJECT_IN_USE             2042L
 #define MQRC_OBJECT_TYPE_ERROR         2043L
 #define MQRC_OD_ERROR                  2044L
 #define MQRC_OPTION_NOT_VALID_FOR_TYPE 2045L
 #define MQRC_OPTIONS_ERROR             2046L
 #define MQRC_PERSISTENCE_ERROR         2047L
 #define MQRC_PERSISTENT_NOT_ALLOWED    2048L
 #define MQRC_PRIORITY_EXCEEDS_MAXIMUM  2049L
 #define MQRC_PRIORITY_ERROR            2050L
 #define MQRC_PUT_INHIBITED             2051L
 #define MQRC_Q_DELETED                 2052L
 #define MQRC_Q_FULL                    2053L
 #define MQRC_Q_NOT_EMPTY               2055L
 #define MQRC_Q_SPACE_NOT_AVAILABLE     2056L
 #define MQRC_Q_TYPE_ERROR              2057L
 #define MQRC_Q_MGR_NAME_ERROR          2058L
 #define MQRC_Q_MGR_NOT_AVAILABLE       2059L
 #define MQRC_REPORT_OPTIONS_ERROR      2061L
 #define MQRC_SECOND_MARK_NOT_ALLOWED   2062L
 #define MQRC_SECURITY_ERROR            2063L
 #define MQRC_SELECTOR_COUNT_ERROR      2065L
 #define MQRC_SELECTOR_LIMIT_EXCEEDED   2066L
 #define MQRC_SELECTOR_ERROR            2067L
 #define MQRC_SELECTOR_NOT_FOR_TYPE     2068L
 #define MQRC_SIGNAL_OUTSTANDING        2069L
 #define MQRC_SIGNAL_REQUEST_ACCEPTED   2070L
 #define MQRC_STORAGE_NOT_AVAILABLE     2071L
 #define MQRC_SYNCPOINT_NOT_AVAILABLE   2072L
 #define MQRC_TRIGGER_CONTROL_ERROR     2075L
 #define MQRC_TRIGGER_DEPTH_ERROR       2076L
 #define MQRC_TRIGGER_MSG_PRIORITY_ERR  2077L
 #define MQRC_TRIGGER_TYPE_ERROR        2078L
 #define MQRC_TRUNCATED_MSG_ACCEPTED    2079L
 #define MQRC_TRUNCATED_MSG_FAILED      2080L
 #define MQRC_UNKNOWN_ALIAS_BASE_Q      2082L
 #define MQRC_UNKNOWN_OBJECT_NAME       2085L
 #define MQRC_UNKNOWN_OBJECT_Q_MGR      2086L
 #define MQRC_UNKNOWN_REMOTE_Q_MGR      2087L
 #define MQRC_WAIT_INTERVAL_ERROR       2090L
 #define MQRC_XMIT_Q_TYPE_ERROR         2091L
 #define MQRC_XMIT_Q_USAGE_ERROR        2092L
 #define MQRC_NOT_OPEN_FOR_PASS_ALL     2093L
 #define MQRC_NOT_OPEN_FOR_PASS_IDENT   2094L
 #define MQRC_NOT_OPEN_FOR_SET_ALL      2095L
 #define MQRC_NOT_OPEN_FOR_SET_IDENT    2096L
 #define MQRC_CONTEXT_HANDLE_ERROR      2097L
 #define MQRC_CONTEXT_NOT_AVAILABLE     2098L
 #define MQRC_SIGNAL1_ERROR             2099L
 #define MQRC_OBJECT_ALREADY_EXISTS     2100L
 #define MQRC_OBJECT_DAMAGED            2101L
 #define MQRC_RESOURCE_PROBLEM          2102L
 #define MQRC_ANOTHER_Q_MGR_CONNECTED   2103L
 #define MQRC_UNKNOWN_REPORT_OPTION     2104L
 #define MQRC_SUPPRESSED_BY_EXIT        2109L
 #define MQRC_FORMAT_ERROR              2110L
 #define MQRC_SOURCE_CCSID_ERROR        2111L
 #define MQRC_SOURCE_INTEGER_ENC_ERROR  2112L
 #define MQRC_SOURCE_DECIMAL_ENC_ERROR  2113L
 #define MQRC_SOURCE_FLOAT_ENC_ERROR    2114L
 #define MQRC_TARGET_CCSID_ERROR        2115L
 #define MQRC_TARGET_INTEGER_ENC_ERROR  2116L
 #define MQRC_TARGET_DECIMAL_ENC_ERROR  2117L
 #define MQRC_TARGET_FLOAT_ENC_ERROR    2118L
 #define MQRC_NOT_CONVERTED             2119L
 #define MQRC_CONVERTED_MSG_TOO_BIG     2120L
 #define MQRC_ADAPTER_STORAGE_SHORTAGE  2127L
 #define MQRC_ADAPTER_CONN_LOAD_ERROR   2129L
 #define MQRC_ADAPTER_SERV_LOAD_ERROR   2130L
 #define MQRC_ADAPTER_DEFS_ERROR        2131L
 #define MQRC_ADAPTER_DEFS_LOAD_ERROR   2132L
 #define MQRC_ADAPTER_DISC_LOAD_ERROR   2138L
 #define MQRC_CICS_WAIT_FAILED          2140L
 #define MQRC_SOURCE_LENGTH_ERROR       2143L
 #define MQRC_TARGET_LENGTH_ERROR       2144L
 #define MQRC_SOURCE_BUFFER_ERROR       2145L
 #define MQRC_TARGET_BUFFER_ERROR       2146L
 #define MQRC_DBCS_ERROR                2150L
 #define MQRC_TRUNCATED                 2151L
 #define MQRC_ASID_MISMATCH             2157L
 #define MQRC_CONN_ID_IN_USE            2160L
 #define MQRC_Q_MGR_QUIESCING           2161L
 #define MQRC_Q_MGR_STOPPING            2162L
 #define MQRC_DUPLICATE_RECOV_COORD     2163L
 #define MQRC_PMO_ERROR                 2173L
 #define MQRC_API_EXIT_NOT_FOUND        2182L
 #define MQRC_API_EXIT_LOAD_ERROR       2183L
 #define MQRC_REMOTE_Q_NAME_ERROR       2184L
 #define MQRC_GMO_ERROR                 2186L
 #define MQRC_PAGESET_FULL              2192L
 #define MQRC_PAGESET_ERROR             2193L
 #define MQRC_NAME_NOT_VALID_FOR_TYPE   2194L
 #define MQRC_UNEXPECTED_ERROR          2195L
 #define MQRC_UNKNOWN_XMIT_Q            2196L
 #define MQRC_UNKNOWN_DEF_XMIT_Q        2197L
 #define MQRC_DEF_XMIT_Q_TYPE_ERROR     2198L
 #define MQRC_DEF_XMIT_Q_USAGE_ERROR    2199L
 #define MQRC_NAME_IN_USE               2201L
 #define MQRC_CONNECTION_QUIESCING      2202L
 #define MQRC_CONNECTION_STOPPING       2203L
 #define MQRC_ADAPTER_NOT_AVAILABLE     2204L
 #define MQRC_MSG_ID_ERROR              2206L
 #define MQRC_CORREL_ID_ERROR           2207L
 #define MQRC_FILE_SYSTEM_ERROR         2208L
 #define MQRC_NO_MSG_LOCKED             2209L
 #define MQRC_FILE_NOT_AUDITED          2216L
 #define MQRC_CONNECTION_NOT_AUTHORIZED 2217L
 #define MQRC_MSG_TOO_BIG_FOR_CHANNEL   2218L
 #define MQRC_CALL_IN_PROGRESS          2219L
 #define MQRC_Q_MGR_ACTIVE              2222L
 #define MQRC_Q_MGR_NOT_ACTIVE          2223L
 #define MQRC_Q_DEPTH_HIGH              2224L
 #define MQRC_Q_DEPTH_LOW               2225L
 #define MQRC_Q_SERVICE_INTERVAL_HIGH   2226L
 #define MQRC_Q_SERVICE_INTERVAL_OK     2227L
 #define MQRC_HCONFIG_ERROR             2280L
 #define MQRC_FUNCTION_ERROR            2281L
 #define MQRC_CHANNEL_STARTED           2282L
 #define MQRC_CHANNEL_STOPPED           2283L
 #define MQRC_CHANNEL_CONV_ERROR        2284L
 #define MQRC_SERVICE_NOT_AVAILABLE     2285L
 #define MQRC_INITIALIZATION_FAILED     2286L
 #define MQRC_TERMINATION_FAILED        2287L
 #define MQRC_UNKNOWN_Q_NAME            2288L
 #define MQRC_SERVICE_ERROR             2289L
 #define MQRC_Q_ALREADY_EXISTS          2290L
 #define MQRC_USER_ID_NOT_AVAILABLE     2291L
 #define MQRC_UNKNOWN_ENTITY            2292L
 #define MQRC_UNKNOWN_AUTH_ENTITY       2293L
 #define MQRC_UNKNOWN_REF_OBJECT        2294L
 #define MQRC_CHANNEL_ACTIVATED         2295L
 #define MQRC_CHANNEL_NOT_ACTIVATED     2296L


 /*********************************************************************/
 /*  Values Related to Queue Attributes                               */
 /*********************************************************************/

 /* Queue Types */
 #define MQQT_LOCAL  1L
 #define MQQT_MODEL  2L
 #define MQQT_ALIAS  3L
 #define MQQT_REMOTE 6L

 /* Extended Queue Types */
 #define MQQT_ALL 1001L

 /* Queue Definition Types */
 #define MQQDT_PREDEFINED        1L
 #define MQQDT_PERMANENT_DYNAMIC 2L
 #define MQQDT_TEMPORARY_DYNAMIC 3L

 /* Inhibit Get */
 #define MQQA_GET_INHIBITED 1L
 #define MQQA_GET_ALLOWED   0L

 /* Inhibit Put */
 #define MQQA_PUT_INHIBITED 1L
 #define MQQA_PUT_ALLOWED   0L

 /* Queue Shareability */
 #define MQQA_SHAREABLE     1L
 #define MQQA_NOT_SHAREABLE 0L

 /* Back-Out Hardening */
 #define MQQA_BACKOUT_HARDENED     1L
 #define MQQA_BACKOUT_NOT_HARDENED 0L

 /* Message Delivery Sequence */
 #define MQMDS_PRIORITY 0L
 #define MQMDS_FIFO     1L

 /* Trigger Control */
 #define MQTC_OFF 0L
 #define MQTC_ON  1L

 /* Trigger Types */
 #define MQTT_NONE  0L
 #define MQTT_FIRST 1L
 #define MQTT_EVERY 2L
 #define MQTT_DEPTH 3L

 /* Queue Usage */
 #define MQUS_NORMAL       0L
 #define MQUS_TRANSMISSION 1L


 /*********************************************************************/
 /*  Values Related to Process-Definition Attributes                  */
 /*********************************************************************/

 /* Application Types */
 /* See values for "Put Application Types" above */


 /*********************************************************************/
 /*  Values Related to Queue-Manager Attributes                       */
 /*********************************************************************/

 /* Command Level */
 #define MQCMDL_LEVEL_1   100L
 #define MQCMDL_LEVEL_114 114L
 #define MQCMDL_LEVEL_201 201L
 #define MQCMDL_LEVEL_221 221L
 #define MQCMDL_LEVEL_320 320L

 /* Platform */
 #define MQPL_MVS   1L
 #define MQPL_OS2   2L
 #define MQPL_AIX   3L
 #define MQPL_UNIX  3L
 #define MQPL_OS400 4L
 #define MQPL_WINDOWS_NT 11L

 /* Syncpoint Availability */
 #define MQSP_AVAILABLE     1L
 #define MQSP_NOT_AVAILABLE 0L


 /*********************************************************************/
 /*  Simple Data Types                                                */
 /*********************************************************************/

 /* Byte Datatypes */
 typedef unsigned char MQBYTE;
 typedef MQBYTE MQPOINTER PMQBYTE;
 typedef MQBYTE MQBYTE16[16];
 typedef MQBYTE16 MQPOINTER PMQBYTE16;
 typedef MQBYTE MQBYTE24[24];
 typedef MQBYTE24 MQPOINTER PMQBYTE24;
 typedef MQBYTE MQBYTE32[32];
 typedef MQBYTE32 MQPOINTER PMQBYTE32;

 /* Character Datatypes */
 typedef char MQCHAR;
 typedef MQCHAR MQPOINTER PMQCHAR;
 typedef MQCHAR MQCHAR4[4];
 typedef MQCHAR4 MQPOINTER PMQCHAR4;
 typedef MQCHAR MQCHAR8[8];
 typedef MQCHAR8 MQPOINTER PMQCHAR8;
 typedef MQCHAR MQCHAR12[12];
 typedef MQCHAR12 MQPOINTER PMQCHAR12;
 typedef MQCHAR MQCHAR28[28];
 typedef MQCHAR28 MQPOINTER PMQCHAR28;
 typedef MQCHAR MQCHAR32[32];
 typedef MQCHAR32 MQPOINTER PMQCHAR32;
 typedef MQCHAR MQCHAR48[48];
 typedef MQCHAR48 MQPOINTER PMQCHAR48;
 typedef MQCHAR MQCHAR64[64];
 typedef MQCHAR64 MQPOINTER PMQCHAR64;
 typedef MQCHAR MQCHAR128[128];
 typedef MQCHAR128 MQPOINTER PMQCHAR128;
 typedef MQCHAR MQCHAR256[256];
 typedef MQCHAR256 MQPOINTER PMQCHAR256;

 /* Other Datatypes */
 typedef long MQLONG;
 typedef MQLONG MQPOINTER PMQLONG;
 typedef MQLONG MQHCONN;
 typedef MQHCONN MQPOINTER PMQHCONN;
 typedef MQLONG MQHOBJ;
 typedef MQHOBJ MQPOINTER PMQHOBJ;
 typedef void MQPOINTER MQPTR;
 typedef MQPTR MQPOINTER PMQPTR;
 typedef void MQPOINTER PMQVOID;
 typedef PMQVOID MQPOINTER PPMQVOID;


 /*********************************************************************/
 /*  MQDLH Structure                                                  */
 /*********************************************************************/

 typedef struct tagMQDLH {
   MQCHAR4   StrucId;         /* Structure identifier */
   MQLONG    Version;         /* Structure version number */
   MQLONG    Reason;          /* Reason message arrived on dead-letter
                                 (undelivered-message) queue */
   MQCHAR48  DestQName;       /* Name of original destination queue */
   MQCHAR48  DestQMgrName;    /* Name of original destination queue
                                 manager */
   MQLONG    Encoding;        /* Original data encoding */
   MQLONG    CodedCharSetId;  /* Original coded character set
                                 identifier */
   MQCHAR8   Format;          /* Original format name */
   MQLONG    PutApplType;     /* Type of application that put message on
                                 dead-letter (undelivered-message)
                                 queue */
   MQCHAR28  PutApplName;     /* Name of application that put message on
                                 dead-letter (undelivered-message)
                                 queue */
   MQCHAR8   PutDate;         /* Date when message was put on
                                 dead-letter (undelivered-message)
                                 queue */
   MQCHAR8   PutTime;         /* Time when message was put on the
                                 dead-letter (undelivered-message)
                                 queue */
  } MQDLH;
 typedef MQDLH MQPOINTER PMQDLH;

 #define MQDLH_DEFAULT {MQDLH_STRUC_ID_ARRAY},\
                       MQDLH_VERSION_1,\
                       MQRC_NONE,\
                       {""},\
                       {""},\
                       0L,\
                       0L,\
                       {MQFMT_NONE_ARRAY},\
                       0L,\
                       {""},\
                       {""},\
                       {""}


 /*********************************************************************/
 /*  MQGMO Structure                                                  */
 /*********************************************************************/

 typedef struct tagMQGMO {
   MQCHAR4   StrucId;        /* Structure identifier */
   MQLONG    Version;        /* Structure version number */
   MQLONG    Options;        /* Options that control the action of
                                MQGET */
   MQLONG    WaitInterval;   /* Wait interval */
   MQLONG    Signal1;        /* Signal */
   MQLONG    Signal2;        /* Reserved */
   MQCHAR48  ResolvedQName;  /* Resolved name of destination queue */
  } MQGMO;
 typedef MQGMO MQPOINTER PMQGMO;

 #define MQGMO_DEFAULT {MQGMO_STRUC_ID_ARRAY},\
                       MQGMO_VERSION_1,\
                       MQGMO_NO_WAIT,\
                       0L,\
                       0L,\
                       0L,\
                       {""}


 /*********************************************************************/
 /*  MQMD Structure                                                   */
 /*********************************************************************/

 typedef struct tagMQMD {
   MQCHAR4   StrucId;           /* Structure identifier */
   MQLONG    Version;           /* Structure version number */
   MQLONG    Report;            /* Report options */
   MQLONG    MsgType;           /* Message type */
   MQLONG    Expiry;            /* Expiry time */
   MQLONG    Feedback;          /* Feedback or reason code */
   MQLONG    Encoding;          /* Data encoding */
   MQLONG    CodedCharSetId;    /* Coded character set identifier */
   MQCHAR8   Format;            /* Format name */
   MQLONG    Priority;          /* Message priority */
   MQLONG    Persistence;       /* Message persistence */
   MQBYTE24  MsgId;             /* Message identifier */
   MQBYTE24  CorrelId;          /* Correlation identifier */
   MQLONG    BackoutCount;      /* Backout counter */
   MQCHAR48  ReplyToQ;          /* Name of reply-to queue */
   MQCHAR48  ReplyToQMgr;       /* Name of reply queue manager */
   MQCHAR12  UserIdentifier;    /* User identifier */
   MQBYTE32  AccountingToken;   /* Accounting token */
   MQCHAR32  ApplIdentityData;  /* Application data relating to
                                   identity */
   MQLONG    PutApplType;       /* Type of application that put the
                                   message */
   MQCHAR28  PutApplName;       /* Name of application that put the
                                   message */
   MQCHAR8   PutDate;           /* Date when message was put */
   MQCHAR8   PutTime;           /* Time when message was put */
   MQCHAR4   ApplOriginData;    /* Application data relating to
                                   origin */
  } MQMD;
 typedef MQMD MQPOINTER PMQMD;

 #define MQMD_DEFAULT {MQMD_STRUC_ID_ARRAY},\
                      MQMD_VERSION_1,\
                      MQRO_NONE,\
                      MQMT_DATAGRAM,\
                      MQEI_UNLIMITED,\
                      MQFB_NONE,\
                      MQENC_NATIVE,\
                      MQCCSI_Q_MGR,\
                      {MQFMT_NONE_ARRAY},\
                      MQPRI_PRIORITY_AS_Q_DEF,\
                      MQPER_PERSISTENCE_AS_Q_DEF,\
                      {MQMI_NONE_ARRAY},\
                      {MQCI_NONE_ARRAY},\
                      0L,\
                      {""},\
                      {""},\
                      {""},\
                      {MQACT_NONE_ARRAY},\
                      {""},\
                      MQAT_NO_CONTEXT,\
                      {""},\
                      {""},\
                      {""},\
                      {""}


 /*********************************************************************/
 /*  MQOD Structure                                                   */
 /*********************************************************************/

 typedef struct tagMQOD {
   MQCHAR4   StrucId;          /* Structure identifier */
   MQLONG    Version;          /* Structure version number */
   MQLONG    ObjectType;       /* Object type */
   MQCHAR48  ObjectName;       /* Object name */
   MQCHAR48  ObjectQMgrName;   /* Object queue manager name */
   MQCHAR48  DynamicQName;     /* Dynamic queue name */
   MQCHAR12  AlternateUserId;  /* Alternate user identifier */
  } MQOD;
 typedef MQOD MQPOINTER PMQOD;

 #define MQOD_DEFAULT {MQOD_STRUC_ID_ARRAY},\
                      MQOD_VERSION_1,\
                      MQOT_Q,\
                      {""},\
                      {""},\
                      {"AMQ.*"},\
                      {""}


 /*********************************************************************/
 /*  MQPMO Structure                                                  */
 /*********************************************************************/

 typedef struct tagMQPMO {
   MQCHAR4   StrucId;           /* Structure identifier */
   MQLONG    Version;           /* Structure version number */
   MQLONG    Options;           /* Options that control the action of
                                   MQPUT or MQPUT1 */
   MQLONG    Timeout;           /* Reserved */
   MQHOBJ    Context;           /* Object handle of input queue */
   MQLONG    KnownDestCount;    /* Reserved */
   MQLONG    UnknownDestCount;  /* Reserved */
   MQLONG    InvalidDestCount;  /* Reserved */
   MQCHAR48  ResolvedQName;     /* Resolved name of destination queue */
   MQCHAR48  ResolvedQMgrName;  /* Resolved name of destination queue
                                   manager */
  } MQPMO;
 typedef MQPMO MQPOINTER PMQPMO;

 #define MQPMO_DEFAULT {MQPMO_STRUC_ID_ARRAY},\
                       MQPMO_VERSION_1,\
                       MQPMO_NONE,\
                       (-1L),\
                       0L,\
                       0L,\
                       0L,\
                       0L,\
                       {""},\
                       {""}


 /*********************************************************************/
 /*  MQTM Structure                                                   */
 /*********************************************************************/

 typedef struct tagMQTM {
   MQCHAR4    StrucId;      /* Structure identifier */
   MQLONG     Version;      /* Structure version number */
   MQCHAR48   QName;        /* Name of triggered queue */
   MQCHAR48   ProcessName;  /* Name of process object */
   MQCHAR64   TriggerData;  /* Trigger data */
   MQLONG     ApplType;     /* Application type */
   MQCHAR256  ApplId;       /* Application identifier */
   MQCHAR128  EnvData;      /* Environment data */
   MQCHAR128  UserData;     /* User data */
  } MQTM;
 typedef MQTM MQPOINTER PMQTM;

 #define MQTM_DEFAULT {MQTM_STRUC_ID_ARRAY},\
                      MQTM_VERSION_1,\
                      {""},\
                      {""},\
                      {""},\
                      0L,\
                      {""},\
                      {""},\
                      {""}


 /*********************************************************************/
 /*  MQTMC2 Structure                                                 */
 /*********************************************************************/

 typedef struct tagMQTMC2 {
   MQCHAR4    StrucId;      /* Structure identifier */
   MQCHAR4    Version;      /* Structure version number */
   MQCHAR48   QName;        /* Name of triggered queue */
   MQCHAR48   ProcessName;  /* Name of process object */
   MQCHAR64   TriggerData;  /* Trigger data */
   MQCHAR4    ApplType;     /* Application type */
   MQCHAR256  ApplId;       /* Application identifier */
   MQCHAR128  EnvData;      /* Environment data */
   MQCHAR128  UserData;     /* User data */
   MQCHAR48   QMgrName;     /* Queue manager name */
  } MQTMC2;
 typedef MQTMC2 MQPOINTER PMQTMC2;

 #define MQTMC2_DEFAULT {MQTMC_STRUC_ID_ARRAY},\
                        {MQTMC_VERSION_2_ARRAY},\
                        {""},\
                        {""},\
                        {""},\
                        {""},\
                        {""},\
                        {""},\
                        {""},\
                        {""}


 /*********************************************************************/
 /*  MQXQH Structure                                                  */
 /*********************************************************************/

 typedef struct tagMQXQH {
   MQCHAR4   StrucId;         /* Structure identifier */
   MQLONG    Version;         /* Structure version number */
   MQCHAR48  RemoteQName;     /* Name of destination queue */
   MQCHAR48  RemoteQMgrName;  /* Name of destination queue manager */
   MQMD      MsgDesc;         /* Original message descriptor */
  } MQXQH;
 typedef MQXQH MQPOINTER PMQXQH;

 #define MQXQH_DEFAULT {MQXQH_STRUC_ID_ARRAY},\
                       MQXQH_VERSION_1,\
                       {""},\
                       {""},\
                       {MQMD_DEFAULT}


 /*********************************************************************/
 /*  MQBACK Function -- Back Out Changes                              */
 /*********************************************************************/

 void MQENTRY MQBACK (
   MQHCONN  Hconn,      /* Connection handle */
   PMQLONG  pCompCode,  /* Completion code */
   PMQLONG  pReason);   /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQCLOSE Function -- Close Object                                 */
 /*********************************************************************/

 void MQENTRY MQCLOSE (
   MQHCONN  Hconn,      /* Connection handle */
   PMQHOBJ  pHobj,      /* Object handle */
   MQLONG   Options,    /* Options that control the action of MQCLOSE */
   PMQLONG  pCompCode,  /* Completion code */
   PMQLONG  pReason);   /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQCMIT Function -- Commit Changes                                */
 /*********************************************************************/

 void MQENTRY MQCMIT (
   MQHCONN  Hconn,      /* Connection handle */
   PMQLONG  pCompCode,  /* Completion code */
   PMQLONG  pReason);   /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQCONN Function -- Connect Queue Manager                         */
 /*********************************************************************/

 void MQENTRY MQCONN (
   PMQCHAR   pName,      /* Name of queue manager */
   PMQHCONN  pHconn,     /* Connection handle */
   PMQLONG   pCompCode,  /* Completion code */
   PMQLONG   pReason);   /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQDISC Function -- Disconnect Queue Manager                      */
 /*********************************************************************/

 void MQENTRY MQDISC (
   PMQHCONN  pHconn,     /* Connection handle */
   PMQLONG   pCompCode,  /* Completion code */
   PMQLONG   pReason);   /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQGET Function -- Get Message                                    */
 /*********************************************************************/

 void MQENTRY MQGET (
   MQHCONN  Hconn,         /* Connection handle */
   MQHOBJ   Hobj,          /* Object handle */
   PMQVOID  pMsgDesc,      /* Message descriptor */
   PMQVOID  pGetMsgOpts,   /* Options that control the action of
                              MQGET */
   MQLONG   BufferLength,  /* Length in bytes of the Buffer area */
   PMQVOID  pBuffer,       /* Area to contain the message data */
   PMQLONG  pDataLength,   /* Length of the message */
   PMQLONG  pCompCode,     /* Completion code */
   PMQLONG  pReason);      /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQINQ Function -- Inquire Object Attributes                      */
 /*********************************************************************/

 void MQENTRY MQINQ (
   MQHCONN  Hconn,           /* Connection handle */
   MQHOBJ   Hobj,            /* Object handle */
   MQLONG   SelectorCount,   /* Count of selectors */
   PMQLONG  pSelectors,      /* Array of attribute selectors */
   MQLONG   IntAttrCount,    /* Count of integer attributes */
   PMQLONG  pIntAttrs,       /* Array of integer attributes */
   MQLONG   CharAttrLength,  /* Length of character attributes buffer */
   PMQCHAR  pCharAttrs,      /* Character attributes */
   PMQLONG  pCompCode,       /* Completion code */
   PMQLONG  pReason);        /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQOPEN Function -- Open Object                                   */
 /*********************************************************************/

 void MQENTRY MQOPEN (
   MQHCONN  Hconn,      /* Connection handle */
   PMQVOID  pObjDesc,   /* Object descriptor */
   MQLONG   Options,    /* Options that control the action of MQOPEN */
   PMQHOBJ  pHobj,      /* Object handle */
   PMQLONG  pCompCode,  /* Completion code */
   PMQLONG  pReason);   /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQPUT Function -- Put Message                                    */
 /*********************************************************************/

 void MQENTRY MQPUT (
   MQHCONN  Hconn,         /* Connection handle */
   MQHOBJ   Hobj,          /* Object handle */
   PMQVOID  pMsgDesc,      /* Message descriptor */
   PMQVOID  pPutMsgOpts,   /* Options that control the action of
                              MQPUT */
   MQLONG   BufferLength,  /* Length of the message in Buffer */
   PMQVOID  pBuffer,       /* Message data */
   PMQLONG  pCompCode,     /* Completion code */
   PMQLONG  pReason);      /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQPUT1 Function -- Put One Message                               */
 /*********************************************************************/

 void MQENTRY MQPUT1 (
   MQHCONN  Hconn,         /* Connection handle */
   PMQVOID  pObjDesc,      /* Object descriptor */
   PMQVOID  pMsgDesc,      /* Message descriptor */
   PMQVOID  pPutMsgOpts,   /* Options that control the action of
                              MQPUT1 */
   MQLONG   BufferLength,  /* Length of the message in Buffer */
   PMQVOID  pBuffer,       /* Message data */
   PMQLONG  pCompCode,     /* Completion code */
   PMQLONG  pReason);      /* Reason code qualifying CompCode */


 /*********************************************************************/
 /*  MQSET Function -- Set Object Attributes                          */
 /*********************************************************************/

 void MQENTRY MQSET (
   MQHCONN  Hconn,           /* Connection handle */
   MQHOBJ   Hobj,            /* Object handle */
   MQLONG   SelectorCount,   /* Count of selectors */
   PMQLONG  pSelectors,      /* Array of attribute selectors */
   MQLONG   IntAttrCount,    /* Count of integer attributes */
   PMQLONG  pIntAttrs,       /* Array of integer attributes */
   MQLONG   CharAttrLength,  /* Length of character attributes buffer */
   PMQCHAR  pCharAttrs,      /* Character attributes */
   PMQLONG  pCompCode,       /* Completion code */
   PMQLONG  pReason);        /* Reason code qualifying CompCode */


 #if defined(__cplusplus)
   }
 #endif

 #endif  /* End of header file */
